#!/usr/local/bin/python

# Copyright (c) 2001 Nathan Sharfi
# This software is provided 'as-is', without any express or implied
# warranty. In no event will the author be held liable for any
# damages arising from the use of this software.
# 
# Permission is granted to anyone to use this software for any
# purpose, including commercial applications, and to alter it and
# redistribute it freely, subject to the following restrictions:
#
# 1. The origin of this software must not be misrepresented; you must
# not claim that you wrote the original software. If you use this
# software in a product, an acknowledgment in the product
# documentation would be appreciated but is not required.
# 
# 2. Altered source versions must be plainly marked as such, and must
# not be misrepresented as being the original software.
# 
# 3. This notice may not be removed or altered from any source
# distribution.

import os
#####################################################################
def getListing(ext, dir="."):
	"""	gets a listing of files matching an extension in a given directory
		defaults to the current directory."""
	list = [	os.path.normcase(f) for f in os.listdir(dir)]
	list = [	os.path.join(dir, f) for f in list if \
				os.path.splitext(f)[1] == ext]
	list.sort()
	return list

#####################################################################
def changeExt(file, newext):
	return os.path.splitext(file)[0] + newext

#####################################################################
def moveBunch(ext, dest, src="."):
	"""Move a directoryful of files with a particular extension
	somewhere else.
	"""
	q = getListing(ext)
	for f in q:
		os.renames(f, os.path.join(dest, f))

#####################################################################
def deflac(indir=".", outdir=".", filelistname=None):
	"""decompress a .flac file to its corresponding .wav file."""
	if filelistname == None:
		files = getListing(".flac", indir)
	else:
		files = filelistname
	
	# if outdir ain't there, make it
	if os.path.isdir(outdir) == 0:
		os.mkdir(outdir)
		
	for pff in files:	# pathed flac file
		(dummy, upff) = os.path.split(pff)
		pwf = os.path.join(outdir, changeExt(upff, ".wav"))
		print "decompressing %s..." % (pff)
		os.system("flac -d -s -o \"%s\" \"%s\"" % (pwf, pff))

#####################################################################
def oggenc(inputFileName, outputFileName=None, quality=None,
			comments=None, quiet=None):
	"""Runs oggenc on the file specified in inputFileName.
	
	doesn't return anything interesting.
	"""
	# argument checking battery...
	if quality < 0 or 10 < quality:
		raise ValueError, "quality must be on [0, 10]"
	
	
	# now, for the meat 'n potatoes...
	cmd = ""
	
	cmd += " --quality " + str(quality) + " "

	if quiet:
		cmd += " --quiet "

	commentlist = []
	for k, a in comments.items():
		for v in a:
			commentlist.append(""" --comment="%s=%s" """ % (k, v))
	
	cmd += " ".join(commentlist)

	
	cmd += " " + inputFileName
	print "the command is: ", cmd
	os.system(cmd)
#####################################################################
if __name__ == "__main__":
	print "these are the comatoys."
	print "testing oggenc wrapper..."
	oggenc(sys.argv[0])
