#!/usr/local/bin/python

# Copyright (c) 2001 Nathan Sharfi
# This software is provided 'as-is', without any express or implied
# warranty. In no event will the author be held liable for any
# damages arising from the use of this software.
# 
# Permission is granted to anyone to use this software for any
# purpose, including commercial applications, and to alter it and
# redistribute it freely, subject to the following restrictions:
#
# 1. The origin of this software must not be misrepresented; you must
# not claim that you wrote the original software. If you use this
# software in a product, an acknowledgment in the product
# documentation would be appreciated but is not required.
# 
# 2. Altered source versions must be plainly marked as such, and must
# not be misrepresented as being the original software.
# 
# 3. This notice may not be removed or altered from any source
# distribution.
from comatoys import *
import sys
import os
import string
import codecs
#####################################################################
def oggBasket(files=None, indir=".", commentdir=".", outdir="."):
	if files == None:
		wavlist = getListing(".wav", indir)
	else:
		wavlist = files
	
#	print wavlist

	ogglist = [OggGenerator(w, commentdir, outdir) for w in wavlist]
	for o in ogglist:
		o.make()

#####################################################################
class OggGenerator:
	"""Generates an .ogg file given a .wav file and (optionally) one 
	or more text files containing comments so the .ogg will have
	comments built right in.
	"""
	__trackInfo = ""
	__albumInfo = ""
	__wavname = ""
	__oggname = ""
	__comments = {}
	__cmd = ""
	__infodir = ""
	__outdir = ""

	def __init__(self, wavname, infoDir=".", outputDir="."):
		"""Load an OggGenerator with the information it needs to 
		generate an Ogg Vorbis file.

		Keyword arguments:
		wavname		-- the name of the .wav file to encode
		infoDir		-- the directory that contains the two comment
					   files, comments.txt and trackNN.comments.txt	
		"""

		self.__comments = {}
		self.__wavname = wavname
		self.__outdir = outputDir
		self.__trackInfo = os.path.splitext(wavname)[0]
		self.__trackInfo += ".comments.txt"
		self.__trackInfo = os.path.split(self.__trackInfo)[1]
		self.__trackInfo = os.path.join(infoDir, self.__trackInfo)

		self.__albumInfo = os.path.join(infoDir, "comments.txt")
		self.__buildComments(self.__albumInfo)
		self.__buildComments(self.__trackInfo)
		self.__buildCommand()

	def make(self):
		if os.path.isdir(self.__outdir) == 0:
			os.mkdir(self.__outdir)
		#print "the command: ", self.__cmd#.encode("UTF-8")
		os.system(self.__cmd)
	
	def __buildComments(self, filename):
		"""Put the contents of a vorbiscomment-formatted file
		into the internal comments dictionary.
		"""
		filehandle = open(filename, "r")
		#filehandle = codecs.open(filename, "r", "UTF-8") # giving up on utf-8...
		while 1:
			current = filehandle.readline().strip()
			if current[0:3] == "\xef\xbb\xbf": # strip BOM
				current = current[3:]

			if current == "":
			 	break
			(comment, data) = string.split(current, "=", 1)
			if self.__comments.has_key(comment):
				self.__comments[comment].append(data)
			else:
				self.__comments[comment] = [data]
				
		filehandle.close()
		
	def __buildCommand(self):
		"""Generate the command line that's passed to the shell."""
		taglist = []
		for k, a in self.__comments.items():
			for v in a:
				taglist.append("""-c "%s=%s" """ % (k, v))
		print self.__comments
		self.__oggname = self.__comments.get("OVERRIDDENFILENAME", \
						self.__comments.get("TITLE"))[0] + ".ogg"
		self.__oggname = os.path.join(self.__outdir, self.__oggname)
		
		cmd = "uggenc \"%s\" -o \"%s\" %s" % \
				(self.__wavname, self.__oggname, " ".join(taglist))
		
		self.__cmd = cmd
	
#####################################################################
if __name__ == "__main__":
	og = OggGenerator(sys.argv[1], ".", ".")
	og.make()
